@@ -3,8 +3,8 @@ use Moose;
 use MooseX::StrictConstructor;
 use Net::Mosso::CloudFiles::Container;
 use Net::Mosso::CloudFiles::Object;
-use LWP;
-our $VERSION = '0.33';
+use LWP::UserAgent::Determined;
+our $VERSION = '0.34';
 
 my $DEBUG = 0;
 
@@ -16,12 +16,17 @@ has 'ua'          => ( is => 'rw', isa => 'LWP::UserAgent', required => 0 );
 has 'storage_url' => ( is => 'rw', isa => 'Str',            required => 0 );
 has 'token'       => ( is => 'rw', isa => 'Str',            required => 0 );
 
+__PACKAGE__->meta->make_immutable;
+
 sub BUILD {
     my $self = shift;
-    my $ua   = LWP::UserAgent->new(
+    my $ua   = LWP::UserAgent::Determined->new(
         keep_alive            => 10,
         requests_redirectable => [qw(GET HEAD DELETE PUT)],
     );
+    $ua->timing('1,2,4,8,16,32');
+    my $http_codes_hr = $ua->codes_to_determinate();
+    $http_codes_hr->{422} = 1; # used by cloudfiles for upload data corruption
     $ua->timeout( $self->timeout );
     $ua->env_proxy;
     $self->ua($ua);
@@ -50,7 +55,7 @@ sub BUILD {
 sub request {
     my ( $self, $request, $filename ) = @_;
     warn $request->as_string if $DEBUG;
-    my $response = $self->ua->request($request, $filename);
+    my $response = $self->ua->request( $request, $filename );
     warn $response->as_string if $DEBUG;
     return $response;
 }
